package com.rouf69nb.android_broadcaster

import android.content.ComponentName
import android.content.Context
import android.content.Intent
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result




/** AndroidBroadcasterPlugin */
class AndroidBroadcasterPlugin: FlutterPlugin, MethodCallHandler {
  private lateinit var _context: Context
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "com.rouf69nb.android_broadcaster")
    channel.setMethodCallHandler(this)
    _context = flutterPluginBinding.applicationContext
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
        "getPlatformVersion" -> {
          result.success("Android ${android.os.Build.VERSION.RELEASE}")
        }
        "initialize" -> {
             if (call.arguments == null) return
             Helper.setHandle(_context, call.arguments as Long)
             result.success("")
        }
        "broadcastEvent" -> {
            result.success("")
            sendBroadcast(call.arguments)
        }
        else -> {
          result.notImplemented()
        }
    }
  }

    private fun sendBroadcast(arguments: Any) {
        @Suppress("UNCHECKED_CAST") val args:Map<String, String> = arguments as Map<String, String>
        val intent = Intent()
        intent.action = args.getValue("action")
        intent.putExtra("data",args.getValue("data"))
        intent.addFlags(Intent.FLAG_INCLUDE_STOPPED_PACKAGES)
        intent.component = ComponentName(args.getValue("packageName"), args.getValue("receiverClassName"))
        _context.sendBroadcast(intent)
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
